@@ -35,6 +35,15 @@ static FILE *tmp_file;
 
 extern sigset_t sigblockset;
 
+void cleanup(void)
+{
+	if (mode == REPLAY) {
+		fclose (record.file);
+		fclose (tmp_file);
+		unlink (tmpfilename);
+	}
+}
+
 void folder_activate_cb(Widget w, XtPointer client_data, XtPointer cbsp)
 {
 	XmLFolderCallbackStruct *cbs = (XmLFolderCallbackStruct *) cbsp;
