@@ -198,7 +198,7 @@ void create_window(int argc, char *argv[])
         XtSetArg(args[n], XmNcolumns, HOST_NCOLS); n++;
         XtSetArg(args[n], XmNallowColumnResize, True); n++;
         XtSetArg(args[n], XmNcellDefaults, True); n++;
-        XtSetArg(args[n], XmNsimpleWidths, "2c 15c 6c 6c 8c 8c 8c 8c 5c 7c 7c 7c 7c 10c"); n++;
+        XtSetArg(args[n], XmNsimpleWidths, "2c 15c 6c 6c 8c 8c 8c 8c 5c 5c 7c 7c 7c 12c 12c 10c"); n++;
         XtSetArg(args[n], XmNselectionPolicy, XmSELECT_NONE); n++;
         XtSetArg(args[n], XmNcellLeftBorderType, XmBORDER_NONE); n++;
         XtSetArg(args[n], XmNcellRightBorderType, XmBORDER_NONE); n++;
@@ -276,6 +276,20 @@ void create_window(int argc, char *argv[])
                        XmNcellRowSpan, 1,
                        NULL);
 
+	XtVaSetValues (Hostlist,
+                       XmNrowType, XmHEADING,
+                       XmNrow, 0,
+                       XmNcolumn, 14,
+                       XmNcellRowSpan, 1,
+                       NULL);
+
+	XtVaSetValues (Hostlist,
+                       XmNrowType, XmHEADING,
+                       XmNrow, 0,
+                       XmNcolumn, 15,
+                       XmNcellRowSpan, 1,
+                       NULL);
+
         XtVaSetValues (Hostlist,
                        XmNcellDefaults, True,
                        XmNcolumn, 0,
@@ -290,10 +304,22 @@ void create_window(int argc, char *argv[])
 		       XmNcellAlignment, XmALIGNMENT_CENTER,
                        NULL);
 
+	XtVaSetValues (Hostlist,
+                       XmNcellDefaults, True,
+                       XmNcolumn, HOST_COL_SWAPRATE,
+		       XmNcellAlignment, XmALIGNMENT_CENTER,
+                       NULL);
+
+	XtVaSetValues (Hostlist,
+                       XmNcellDefaults, True,
+                       XmNcolumn, HOST_COL_DISKRATE,
+		       XmNcellAlignment, XmALIGNMENT_CENTER,
+                       NULL);
+
         
         XmLGridSetStrings (Hostlist,
-                           "Name||Performance||RAM size in kB||Swap size in kB||Proc|Ctx_sw|Average load|||Reliability\n|"
-                           "|max.|avail.|total|free|total|free|||1min|5min|15min||");
+                           "Name||Performance||RAM size in KB||Swap size in KB||Proc|Ctx|Average load|||Swap in/out|Disk r/w [KB]|Reliability\n|"
+                           "|max.|avail.|total|free|total|free|||1min|5min|15min|||");
 
 	XtAddCallback(Hostlist, XmNselectCallback, host_grid_select_cb, NULL);
 
@@ -361,7 +387,7 @@ void create_window(int argc, char *argv[])
         XtSetArg(args[n], XmNcolumns, DEV_NCOLS); n++;
         XtSetArg(args[n], XmNallowColumnResize, True); n++;
         XtSetArg(args[n], XmNcellDefaults, True); n++;
-        XtSetArg(args[n], XmNsimpleHeadings, "Host|Iface|Status|Tx bytes|Rx bytes|Collisions"); n++;
+        XtSetArg(args[n], XmNsimpleHeadings, "Host|Iface|Status|Transmit|Receive|Collisions"); n++;
         XtSetArg(args[n], XmNsimpleWidths, "15c 8c 6c 9c 9c 9c"); n++;
         XtSetArg(args[n], XmNcellLeftBorderType, XmBORDER_NONE); n++;
         XtSetArg(args[n], XmNcellRightBorderType, XmBORDER_NONE); n++;
@@ -611,4 +637,6 @@ void create_window(int argc, char *argv[])
 			h->pixel = col.pixel;
 		}
 	}
+
+	atexit(cleanup);
 }
\ No newline at end of file
