@@ -55,7 +55,47 @@ void warning (const char *fmt, ...)
         putc ('\n', stderr);
 }
 
-int lprintf (char *buff, char *fmt, ...)
+int kprintf (char *buff, char *fmt, ...)
+{
+        va_list ap;
+        long num = 0;
+        int len = 0;
+        char *c;
+
+        va_start(ap, fmt);
+        for (c = fmt; *c; c++) {
+                if (*c != '%') {
+                        sprintf (buff+len, "%c", *c);
+                        len++;
+                        continue;
+                }
+                c++;
+                switch(*c) {
+/*                case 'L':
+                        num = va_arg(ap, long long);
+                        break;*/
+                case 'l':
+                        num = va_arg(ap, long);
+                        break;
+                }
+                c++;
+		if (num >> 20) {
+                        len += sprintf (buff+len, "%ldG", num >> 20);
+                        continue;
+                }
+                if (num >> 10) {
+                        len += sprintf (buff+len, "%ldM", num >> 10);
+                        continue;
+		}
+		len += sprintf (buff+len, "%ld", num);
+		if (num)
+			len += sprintf (buff+len, "K");
+	}
+        va_end(ap);
+        return len;
+}
+
+int bprintf (char *buff, char *fmt, ...)
 {
         va_list ap;
         long num = 0;
