@@ -318,7 +318,7 @@ void net_curve_update (XmString name, unsigned long value)
         float tdiff = tvaltosec (current_time) - tvaltosec(old_time);
 
         add_value_to_curve (find_curve (net_curves, nnet_curves, name),
-                            value/1024., tdiff);
+                            value, tdiff);
 }
 
 void update_curves_time (int show)
@@ -346,6 +346,7 @@ void update_curves_time (int show)
 }
 
 
+#define sum(type) hi->type[0]+hi->type[1]+hi->type[2]+hi->type[3]
 
 void hostlist_update (struct host_info *host)
 {
@@ -354,12 +355,12 @@ void hostlist_update (struct host_info *host)
 	static char buf[128];
 
         if (!hi || hi->status != HOST_AVAILABLE)
-                sprintf (buf, "%s|%5.2f |not|available||||||| ",
+                sprintf (buf, "%s|%5.2f |not|available||||||||||| ",
 			 hi->name,
 			 hi->performance);
 	else
-		/*                Performance      Ram     Swap  NProc Ctx_swtch  Avg.load        */
-		sprintf (buf, "%s|%5.2f |%5.2f |%ld |%ld |%ld |%ld |%d |%ld |%5.3f |%5.3f |%5.3f |%s",
+		/*                Performance      Ram      Swap  NProc Ctxh       Avg.load     Swap_rate Disk_rate Reliab.   */
+		sprintf (buf, "%s|%5.2f |%5.2f |%ld |%ld |%ld |%ld |%d |%ld |%5.3f |%5.3f |%5.3f |%ld/%ld|%ld/%ld|%s",
 			 hi->name,
 			 hi->performance,
 			 (hi->CPU_available * hi->performance)/ 1e4,
@@ -370,6 +371,8 @@ void hostlist_update (struct host_info *host)
                          hi->procnum,
                          hi->ctx_swtch,
 			 hi->loads[0]/100., hi->loads[1]/100., hi->loads[2]/100.,
+			 hi->swpin, hi->swpout,
+			 sum(disk_read), sum(disk_write),
 			 rel_types[hi->reliability]);
 
         XmLGridSetStringsPos (Hostlist, XmCONTENT, row, XmCONTENT, 1, buf);
@@ -482,22 +485,22 @@ void proc_tree_change(int row, int column, struct cis_procinfo *p)
                 sprintf (buf, "%ld ", p->priority);
                 break;
         case PROC_COL_RSS:
-                lprintf (buf, "%ld ", p->rss);
+		kprintf (buf, "%ld ", p->rss);
                 break;
         case PROC_COL_VM:
-                lprintf (buf, "%ld ", p->vm);
+                kprintf (buf, "%ld ", p->vm);
                 break;
         case PROC_COL_PCPU:
                 sprintf (buf, "%5.2f ", p->pCPU/100.);
                 break;
         case PROC_COL_MAJFLT:
-                lprintf (buf, "%ld ", p->majflt);
+                sprintf (buf, "%ld ", p->majflt);
                 break;
         case PROC_COL_READ:
-                lprintf (buf, "%ld ", p->rd_bytes);
+                kprintf (buf, "%ld ", p->disk_read);
                 break;
         case PROC_COL_WRITE:
-                lprintf (buf, "%ld ", p->wr_bytes);
+                kprintf (buf, "%ld ", p->disk_write);
                 break;
         }
         XmLGridSetStringsPos (Proclist, XmCONTENT, row, XmCONTENT, column, buf);
@@ -764,9 +767,9 @@ void proclist_update (struct host_info *host)
                         if (proclist_sort_type == PROC_SORT_MAJFLT)
 				redraw_tree = TRUE;
 		}
-                if (newp->rd_bytes != p->rd_bytes)
+                if (newp->disk_read != p->disk_read)
 			proc_tree_change (row, PROC_COL_READ, newp);
-                if (newp->wr_bytes != p->wr_bytes)
+                if (newp->disk_write != p->disk_write)
 			proc_tree_change (row, PROC_COL_WRITE, newp);
 
                 XtVaGetValues(Proclist,
@@ -828,11 +831,11 @@ void proclist_update (struct host_info *host)
 			c += sprintf (c, "| %d", p->uid);
 
 		c += sprintf (c, "|%ld ", p->priority);
-		c += lprintf (c, "|%ld |%ld ", p->rss, p->vm);
+		c += kprintf (c, "|%ld |%ld ", p->rss, p->vm);
 		c += sprintf (c, "|%5.2f ", p->pCPU/100.);
-                c += lprintf (c, "|%ld ", p->majflt);
-                c += lprintf (c, "|%ld ", p->rd_bytes);
-                c += lprintf (c, "|%ld ", p->wr_bytes);
+                c += sprintf (c, "|%ld ", p->majflt);
+                c += kprintf (c, "|%ld ", p->disk_read);
+                c += kprintf (c, "|%ld ", p->disk_write);
                 c += tprintf (c, "|%ld ", current_time.tv_sec - p->start_time);
                 c += tprintf (c, "|%ld ", p->utime + p->stime);
 
@@ -1034,7 +1037,7 @@ void linklist_update (void)
                                 len += sprintf (buf+len, " |%d |", link->dst_pid);
 
                         len += sprintf (buf+len, "%s |", (link->type == SOCK_STREAM) ? "TCP" : "UDP");
-                        len += lprintf (buf+len, "%ld |%ld ",
+                        len += bprintf (buf+len, "%ld |%ld ",
                                         link->sent, link->rcvd);
 
 
@@ -1085,7 +1088,7 @@ void linklist_update (void)
                                         len += sprintf (buf+len, " |%d |", link->dst_pid);
 
                                 len += sprintf (buf+len, "%s |", (link->type == SOCK_STREAM) ? "TCP" : "UDP");
-                                len += lprintf (buf+len, "%ld |%ld ",
+				len += bprintf (buf+len, "%ld |%ld ",
                                                 link->sent, link->rcvd);
                                 XmLGridSetStringsPos (Linklist, XmCONTENT, row, XmCONTENT, LINK_COL_DSTHOST, buf);
                         }
@@ -1095,7 +1098,7 @@ void linklist_update (void)
                         l++;
                 }
 
-                lprintf (buf, "%ld |%ld ", h->send_rate, h->recv_rate);
+                bprintf (buf, "%ld |%ld ", h->send_rate, h->recv_rate);
                 XmLGridSetStringsPos (Linklist, XmCONTENT, h->link_offset, XmCONTENT, LINK_COL_SENT, buf);
                 
                 h->link_number = l - h->linklist;
@@ -1112,15 +1115,15 @@ void dev_tree_change(int row, int column, struct cis_netdevinfo *d)
                 break;
                 
         case DEV_COL_RX:
-                lprintf (buf, "%ld ", d->rx_bytes);
+                kprintf (buf, "%ld ", d->receive);
                 break;
                 
         case DEV_COL_TX:
-                lprintf (buf, "%ld ", d->tx_bytes);
+                kprintf (buf, "%ld ", d->transmit);
                 break;
                 
         case DEV_COL_COLL:
-                lprintf (buf, "%ld ", d->collisions);
+                sprintf (buf, "%ld ", d->collisions);
                 break;
         }
 
@@ -1163,7 +1166,7 @@ void devtab_update (struct host_info *host, struct cis_netdevinfo *dtab, int len
 			dev_priv(d)->flags = TRUE;
                 }
                         
-                net_curve_update (dev_priv(dev)->name, dev->tx_bytes);
+                net_curve_update (dev_priv(dev)->name, dev->transmit);
         }
 
         for (d = host->devtab; d < host->devtab+host->ndev; d++)
@@ -1223,11 +1226,11 @@ void devlist_update (struct host_info *host)
 
                 if (newd->status != d->status)
                         dev_tree_change (row, DEV_COL_STATUS , newd);
-                if (newd->rx_bytes != d->rx_bytes)
+                if (newd->receive != d->receive)
                         dev_tree_change (row, DEV_COL_RX , newd);
                 if (newd->collisions != d->collisions)
                         dev_tree_change (row, DEV_COL_COLL , newd);
-                if (newd->tx_bytes != d->tx_bytes)
+                if (newd->transmit != d->transmit)
                         dev_tree_change (row, DEV_COL_TX , newd);
 
 		newd->priv = d->priv;
@@ -1253,8 +1256,9 @@ void devlist_update (struct host_info *host)
                                XmNrowUserData, newd,
                                NULL);
 
-		len = sprintf (buf, "%s|%s|%s|", host->hostinfo->name, d->name, d->status ? "up" : "down");
-                lprintf (buf+len, "%ld |%ld |%ld ", d->tx_bytes, d->rx_bytes, d->collisions);
+		len  = sprintf (buf, "%s|%s|%s|", host->hostinfo->name, d->name, d->status ? "up" : "down");
+		len += kprintf (buf+len, "%ld |%ld ", d->transmit, d->receive);
+		sprintf (buf+len, "|%ld" , d->collisions);
 
                 XmLGridSetStringsPos (Devlist,
                                       XmCONTENT, row,
