@@ -158,7 +158,8 @@ extern struct cisinfo  *cislist;
 
 void fatal_err (const char *fmt, ...);
 void warning (const char *fmt, ...);
-int lprintf (char *buff, char *fmt, ...);
+int bprintf (char *buff, char *fmt, ...);
+int kprintf (char *buff, char *fmt, ...);
 int tprintf (char *buff, char *fmt, ...);
 void getparams (int argc, char **argv);
 void parse_configfile (void);
@@ -237,7 +238,9 @@ enum {
 	HOST_COL_CTX_SWTCH,
         HOST_COL_LOADAVG1,
         HOST_COL_LOADAVG5,
-        HOST_COL_LOADAVG15,
+	HOST_COL_LOADAVG15,
+	HOST_COL_SWAPRATE,
+	HOST_COL_DISKRATE,
         HOST_COL_RELIABILITY,
         HOST_NCOLS,
 };
